function ccshift, x, y, refx, refy, maxshiftx=maxshiftx, $
  normdivide=normdivide, contsubtract=contsubtract, cc=cc

  ; Align two curves by cross-correlation.

  ; Returns the (linear) offset dx that needs to be applied to x 
  ; (x' = x + dx) to make y(x') align with refy(refx).

  n = n_elements(x)
  nref = n_elements(refx)

  if n ne n_elements(y) or nref ne n_elements(refy) then begin
    print, ' Number of elements of each pair must be equal'
    return, !values.f_nan
  endif

  oversamp = 0.1

  ; Determine the common coordinate grid
  dx = abs(median(x[1:*]-x[0:n-1]))
  sdx = dx*oversamp
  nsx = fix(((max(x) < max(refx))-(min(x) > min(refx)))/sdx)
  sx = (min(x) > min(refx)) + sdx*indgen(nsx) ; common x grid

  if n_elements(maxshiftx) gt 0 then maxshiftp = maxshiftx / sdx $
  else maxshiftp = fix(0.25*nsx)

  ; Resample onto the common coordinate grid
  sy = interpol2(y, x, sx)
  srefy = interpol2(refy, refx, sx)

  if keyword_set(normdivide) or keyword_set(contsubtract) then begin

    win0i = indgen(nsx/10)
    win1i = nsx-1-indgen(nsx/10)
    win0x = mean(sx[win0i])
    win1x = mean(sx[win1i])

    win0y = median(sy[win0i], /even)
    win1y = median(sy[win1i], /even)
    b = (win1y-win0y)/(win1x-win0x)
    ppar = [win0y-b*win0x, b]
    model = poly(sx, ppar)
    if keyword_set(normdivide) then sy = sy / model
    if keyword_set(contsubtract) then sy = sy - model

    win0yref = median(srefy[win0i], /even)
    win1yref = median(srefy[win1i], /even)
    b = (win1yref-win0yref)/(win1x-win0x)
    ppar = [win0yref-b*win0x, b]
    modelref = poly(sx, ppar)
    if keyword_set(normdivide) then srefr = srefy / modelref
    if keyword_set(contsubtract) then srefy = srefy - modelref
  endif

  ;window, 2
  ;plot, x, y/max(y), psym=10, /xsty, yrange=[0,1.05], /ysty
  ;oplot, refx, refy, col=rgb(255,255,0), psym=10
  ;oplot, sx, sy/max(sy), col=rgb(255,255,255), linestyle=2
  ;oplot, sx, srefy, col=rgb(150,150,0), linestyle=2

  cshiftp = (indgen(2*maxshiftp+1)-maxshiftp) ; units of dx*oversamp
  cshiftp = cshiftp[where(abs(cshiftp) lt n_elements(sy))]
  cshiftx = cshiftp*sdx
  cc = c_correlate(sy, srefy, cshiftp)

  w = where(cc eq max(cc))
  bestxshift = (cshiftx[w]) [0]

  ;oplot, x+bestxshift, y, col=rgb(0,255,0), psym=10
  ;oplot, sx+bestxshift, sy, col=rgb(0,255,0)
  ;window, 1
  ;plot, cshiftx, cc

  return, bestxshift
end

pro testccshift, offset, noise
  if n_elements(offset) eq 0 then offset = 0.0
  if n_elements(noise) eq 0 then noise = 0.01

  wav = 985 + findgen(90)*0.35
  flux = 1 - 0.35*exp(-((wav-(1000-offset))/3.5)^2) + 0.02*(wav-1000)
  flux = flux + noise*randomn(seed, n_elements(flux))

  rwav = 980 + findgen(110)*0.4
  rflux = 1 - 0.65*exp(-((rwav-(1000))/2.8)^2)

  ; this test shows a systematic offset of 0.1 (0.3 pixel or so..)

  shift = ccshift(wav, flux, rwav, rflux, /contsubtract)
  ; add shift to wav to correct the spectrum.

  print, shift

end
