;+
; NAME: 
;    filterarclist
;
; PURPOSE: 
;    Simple routine to filter a reference list of lines of multiple chemical species
;    to only return lines matching specific desired species.
;
; CALLING SEQUENCE: 
;    list = filterarclist(wav, name, onlampnames, id=id)
;       
; INPUTS:
;    wav - List of wavelengths
;    name - List of line species names (blended lines can be signified as +, e.g. Ne+Ar)
;    onlampnames - List of species to retain.
;
; OPTIONAL INPUT KEYWORD PARAMETERS:
;       
; OPTIONAL OUTPUT KEYWORD PARAMETERS:
;   id - Output list of species names matching the wavelengths below
;       
; OUTPUTS: 
;   list - List of wavelengths of lines in the catalog belonging to the species indicated.
;
; Last modified 18 Sep 2019.  Documentation added 3 July 2022.
;-

function filterarclist, wav, name, onlampnames, id=id

   keep = intarr(n_elements(name)) + 1
   for l = 0, n_elements(name)-1 do begin
      linenames = strsplit(name[l],'+',/extract) ; signify blends with +
      for b = 0, n_elements(linenames)-1 do begin
         if total(linenames[b] eq onlampnames) eq 0 then keep[l] = 0
      endfor
   endfor
   list = wav[where(keep)]
   id = name[where(keep)]

   return, list
end


