;+
; NAME: maxpixel.pro
;
; PURPOSE: 
;   Given a list of x,y coordinates, find the highest pixel value within r pixels of each
;   (Used to check for saturated stars)    
;
; CALLING SEQUENCE: 
;   p = maxpixel(imagename, x, y, r=r)
;       
; INPUTS:
;   imagename - Filename of image to use   
;   x - Initial X coordinates array
;   y - Initial Y coordinates array
;
; OPTIONAL INPUT KEYWORD PARAMETERS:
;   r - "Radius" (pixel offset) to search around each coordinate
;       
; OPTIONAL OUTPUT KEYWORD PARAMETERS: none
;       
; OUTPUTS: 
;   Values of the maximum pixel near each x,y coordinate pair.
;
; REQUIREMENTS: 
;
; Last modified 2 Apr 2012.  Documentation added 2 July 2022.
;-

function maxpixel, imagename, x, y, r=r
   data = mrdfits(imagename, /silent)
   if n_elements(r) eq 0 then r = 2
   nx = (size(data)) [1]
   ny = (size(data)) [2]
   m = fltarr(n_elements(x))
   for i = 0, n_elements(x)-1 do begin
     xi = fix(x[i])
     yi = fix(y[i])
     m[i] = max(data[xi-r>0:xi+r<nx-r,yi-r>0:yi+r<ny-r])
   endfor

   return, m
end


