;+
; NAME: 
;   readzpt
;
; PURPOSE: 
;   Read a zeropoint solution file.    
;
; CALLING SEQUENCE: 
;   zptdata = readzpt(filename, count=count)
;       
; INPUTS:
;   filename - Name of zeropoint solution file.
;       
; OPTIONAL OUTPUT KEYWORD PARAMETERS:
;  count - Contains the number of valid zeropoints in the file (1 per filter). =0 if fails.
;       
; OUTPUTS:
;  zptdata - Structure array containing the zeropoint solution for one or more filters. 
;
; Last modified 4 Sep  2020.  Documentation added 3 July 2022.
;-


function readzpt, filename, count=count

     count = 0
     if file_test(filename) eq 0 then begin
       print, filename, ' not found.'
       return, -1
     endif
     n = countlines(filename)
     zptdata = replicate({config:'', zpt:0., zptunc:0., airterm:0., airtermunc:0., nstar:0, zptrad:0.}, n)
;inst:'', filt:'', filt2:'',
     openr, 1, filename
     inline = ''
     i = 0
     while not eof(1) do begin
        readf, 1, inline
        inline = clip(inline)
        inline = (strsplit(inline,'#',/extract)) [0]
        inarr = strsplit(inline, /extract)
        if n_elements(inarr) lt 3 then continue
        zptdata[i].config = inarr[0]
        zptdata[i].zpt = float(inarr[2])
        zptdata[i].zptunc = float(repstr(repstr(repstr(inarr[3],')',''),'(',''),'-','0'))
        zptdata[i].airterm = float(inarr[4])
        zptdata[i].airtermunc = float(repstr(repstr(repstr(inarr[5],')',''),'(',''),'-','0'))
        zptdata[i].nstar = fix(inarr[6])
        zptdata[i].zptrad = float(repstr(repstr(inarr[7],']',''),'[',''))
        i += 1
     endwhile
     close, 1
     count = i
     if count gt 0 then begin
        zptdata = zptdata[0:count-1] 
     endif else begin 
        zptdata = zptdata[0] ; return a blank structure
     endelse

     return, zptdata
end

