;+
; NAME: 
;   removeduplicatematches
;
; PURPOSE: 
;   Given a list of (candidate) matches between x-coordinates and wavelengths, identify
;   cases where a line in one list has been matched to two different items in the other
;   list and attempt to disambiguate/remove these inconsistent duplicates.
;   Used (only) by solvearc
;
; CALLING SEQUENCE: 
;   removeduplicatematches, xmatch, wavmatch, residual
;       
; INPUTS/OUTPUTS:
;   xmatch   - List of matched x coordinates
;   wavmatch - List of matched wavelengths
;
; INPUTS:
;   residual - Quality indicator of each match (lower=better)
;
; OUTPUTS: 
;   xmatch   - List of matched x coordinates with duplicates removed
;   wavmatch - List of matched wavelengths with duplicates removed
;
; Last modified 25 May 2012.  Documentation added 3 July 2022.
;-

pro removeduplicatematches, xmatch, wavmatch, residual

   uwavmatch = unique(wavmatch)       
   if n_elements(uwavmatch) lt n_elements(wavmatch) then begin
      outmatchi = intarr(n_elements(uwavmatch))
      for iu = 0, n_elements(uwavmatch)-1 do begin
         wm = where(wavmatch eq uwavmatch[iu], ct)
         if ct ge 2 then begin
            outwm = (where(residual[wm] eq min(residual[wm]))) [0]
         endif else begin
            outwm = wm
         endelse
         outmatchi[iu] = wm[outwm]
      endfor
      xmatch = xmatch[outmatchi]
      wavmatch = wavmatch[outmatchi]
   endif

   uxmatch = unique(xmatch)
   if n_elements(uxmatch) lt n_elements(xmatch) then begin
      outmatchi = intarr(n_elements(uxmatch))
      for iu = 0, n_elements(uxmatch)-1 do begin
         wm = where(xmatch eq uxmatch[iu], ct)
         if ct ge 2 then begin
            outwm = (where(residual[wm] eq min(residual[wm]))) [0]
         endif else begin
            outwm = wm
         endelse
         outmatchi[iu] = wm[outwm]
      endfor
      xmatch = xmatch[outmatchi]
      wavmatch = wavmatch[outmatchi]
   endif

end

