function pow, v, ex
   return, v^ex
end

pro sip2pv, infile, outfile, modify=modify

   if keyword_set(modify) then outfile = infile
   if n_elements(outfile) eq 0 then outfile = 'pv'+removepath(infile)
   im = readfits(infile, h)

   naxis1 = sxpar(h,'NAXIS1')
   naxis2 = sxpar(h,'NAXIS2')

   crpix1 = sxpar(h, "CRPIX1")
   crpix2 = sxpar(h, "CRPIX2")

   cd11 = sxpar(h, "CD1_1")
   cd12 = sxpar(h, "CD1_2")
   cd21 = sxpar(h, "CD2_1")
   cd22 = sxpar(h, "CD2_2")

   ; Compute SIP distortion and recompute PV distortion,
   ;  so that CD matrix can be shared by both representations.

   newcd11 = cd11
   newcd12 = cd12
   newcd21 = cd21
   newcd22 = cd22
   detnewcd = (newcd11 * newcd22 - newcd12 * newcd21)

   A_0_2 = sxpar(h, "A_0_2")
   A_0_3 = sxpar(h, "A_0_3")
   A_0_4 = sxpar(h, "A_0_4")
   A_1_1 = sxpar(h, "A_1_1")
   A_1_2 = sxpar(h, "A_1_2")
   A_1_3 = sxpar(h, "A_1_3")
   A_2_0 = sxpar(h, "A_2_0")
   A_2_1 = sxpar(h, "A_2_1")
   A_2_2 = sxpar(h, "A_2_2")
   A_3_0 = sxpar(h, "A_3_0")
   A_3_1 = sxpar(h, "A_3_1")
   A_4_0 = sxpar(h, "A_4_0")
   B_0_2 = sxpar(h, "B_0_2")
   B_0_3 = sxpar(h, "B_0_3")
   B_0_4 = sxpar(h, "B_0_4")
   B_1_1 = sxpar(h, "B_1_1")
   B_1_2 = sxpar(h, "B_1_2")
   B_1_3 = sxpar(h, "B_1_3")
   B_2_0 = sxpar(h, "B_2_0")
   B_2_1 = sxpar(h, "B_2_1")
   B_2_2 = sxpar(h, "B_2_2")
   B_3_0 = sxpar(h, "B_3_0")
   B_3_1 = sxpar(h, "B_3_1")
   B_4_0 = sxpar(h, "B_4_0")

   A_DMAX = 0.0
   B_DMAX = 0.0
   for i = 0,  naxis1-1, 32 do begin
       for j = 0, naxis2-1, 32 do begin
	   u = i - crpix1
           v = j - crpix2
           vraisedto2 = pow(v, 2)
           uraisedto2 = pow(u, 2)
           vraisedto3 = pow(v, 3)
           uraisedto3 = pow(u, 3)
           vraisedto4 = pow(v, 4)
           uraisedto4 = pow(u, 4)
           adistscalar = A_0_2*vraisedto2 + A_0_3*vraisedto3 + A_0_4*vraisedto4 + A_1_1*u*v + $
                A_1_2*u*vraisedto2 + A_1_3*u*vraisedto3 + A_2_0*uraisedto2 + $
                A_2_1*uraisedto2*v + A_2_2*uraisedto2*vraisedto2 + A_3_0*uraisedto3 + $
                A_3_1*uraisedto3*v + A_4_0*uraisedto4
           bdistscalar = B_0_2*vraisedto2 + B_0_3*vraisedto3 + B_0_4*vraisedto4 + B_1_1*u*v + $
                B_1_2*u*vraisedto2 + B_1_3*u*vraisedto3 + B_2_0*uraisedto2 + $
                B_2_1*uraisedto2*v + B_2_2*uraisedto2*vraisedto2 + B_3_0*uraisedto3 + $
                B_3_1*uraisedto3*v + B_4_0*uraisedto4 
           u_p = u + adistscalar
           v_p = v + bdistscalar
           x_p = newcd11 * u_p + newcd12 * v_p
           y_p = newcd21 * u_p + newcd22 * v_p
           x = (cd11 * u + cd12 * v)
           y = (cd21 * u + cd22 * v)
           if (abs(adistscalar) gt A_DMAX) then begin
	        i_maxa = i
		j_maxa = j
		A_DMAX = abs(adistscalar)
                ; printf("-->A_DMAX = %f\n", A_DMAX)
	   endif
           if (abs(bdistscalar) gt B_DMAX) then begin
                j_maxb = j
                i_maxb = i
                B_DMAX = abs(bdistscalar)
	   endif
       endfor
    endfor

    if keyword_set(verbose) then begin
        print, "adistscalar = ", adistscalar
        print, "bdistscalar = ", bdistscalar
        print, "A_DMAX = ", A_DMAX
        print, "B_DMAX = ", B_DMAX
    endif

   detcd = (cd11 * cd22 - cd12 *cd21)
   invcd11 = cd22 / detcd
   invcd12 = -cd12 / detcd
   invcd21 = -cd21 / detcd
   invcd22 = cd11 / detcd

   myzero = 0.0
   myone = 1.0

   sxaddpar, h, "PV1_0", myzero
   sxaddpar, h, "PV2_0", myzero
   sxaddpar, h, "PV1_1", myone
   sxaddpar, h, "PV1_2", myzero
   sxaddpar, h, "PV2_1", myone
   sxaddpar, h, "PV2_2", myzero

   ncd11 = newcd11
   ncd12 = newcd12
   ncd21 = newcd21
   ncd22 = newcd22

   ncd11raisedto2 = pow(ncd11, 2)
   ncd12raisedto2 = pow(ncd12, 2)
   ncd21raisedto2 = pow(ncd21, 2)
   ncd22raisedto2 = pow(ncd22, 2)

   ncd11raisedto3 = pow(ncd11, 3)
   ncd12raisedto3 = pow(ncd12, 3)
   ncd21raisedto3 = pow(ncd21, 3)
   ncd22raisedto3 = pow(ncd22, 3)

   ncd11raisedto4 = pow(ncd11, 4)
   ncd12raisedto4 = pow(ncd12, 4)
   ncd21raisedto4 = pow(ncd21, 4)
   ncd22raisedto4 = pow(ncd22, 4)

   ncd11raisedto5 = pow(ncd11, 5)
   ncd12raisedto5 = pow(ncd12, 5)
   ncd21raisedto5 = pow(ncd21, 5)
   ncd22raisedto5 = pow(ncd22, 5)

   detnewcdraisedto2 = pow(detnewcd, 2)
   detnewcdraisedto3 = pow(detnewcd, 3)
   detnewcdraisedto4 = pow(detnewcd, 4)

   nPV1_4  =  (A_0_2*ncd11*ncd21raisedto2 - $
                       A_1_1*ncd11*ncd21*ncd22 + $
                       A_2_0*ncd11*ncd22raisedto2 + $
                       B_0_2*ncd12*ncd21raisedto2 - $
                       B_1_1*ncd12*ncd21*ncd22 + $
		       B_2_0*ncd12*ncd22raisedto2) / detnewcdraisedto2
   nPV1_5  =  (-2*A_0_2*ncd11raisedto2*ncd21 + $
                       A_1_1*ncd11raisedto2*ncd22 + $
                       A_1_1*ncd11*ncd12*ncd21 - $
                       2*A_2_0*ncd11*ncd12*ncd22 - $
                       2*B_0_2*ncd11*ncd12*ncd21 + $
                       B_1_1*ncd11*ncd12*ncd22 + $
                       B_1_1*ncd12raisedto2*ncd21 - $
		       2*B_2_0*ncd12raisedto2*ncd22) / detnewcdraisedto2
   nPV1_6  =  (A_0_2*ncd11raisedto3 - $
                       A_1_1*ncd11raisedto2*ncd12 + $
                       A_2_0*ncd11*ncd12raisedto2 + $
                       B_0_2*ncd11raisedto2*ncd12 - $
                       B_1_1*ncd11*ncd12raisedto2 + $
		       B_2_0*ncd12raisedto3) / detnewcdraisedto2
   nPV1_7  =  (-A_0_3*ncd11*ncd21raisedto3 + $
                       A_1_2*ncd11*ncd21raisedto2*ncd22 - $
                       A_2_1*ncd11*ncd21*ncd22raisedto2 + $
                       A_3_0*ncd11*ncd22raisedto3 - $
                       B_0_3*ncd12*ncd21raisedto3 + $
                       B_1_2*ncd12*ncd21raisedto2*ncd22 - $
                       B_2_1*ncd12*ncd21*ncd22raisedto2 + $
		       B_3_0*ncd12*ncd22raisedto3) / detnewcdraisedto3
   nPV1_8  =  (3*A_0_3*ncd11raisedto2*ncd21raisedto2 - $
                       2*A_1_2*ncd11raisedto2*ncd21*ncd22 - $
                       A_1_2*ncd11*ncd12*ncd21raisedto2 + $
                       A_2_1*ncd11raisedto2*ncd22raisedto2 + $
                       2*A_2_1*ncd11*ncd12*ncd21*ncd22 - $
                       3*A_3_0*ncd11*ncd12*ncd22raisedto2 + $
                       3*B_0_3*ncd11*ncd12*ncd21raisedto2 - $
                       2*B_1_2*ncd11*ncd12*ncd21*ncd22 - $
                       B_1_2*ncd12raisedto2*ncd21raisedto2 + $
                       B_2_1*ncd11*ncd12*ncd22raisedto2 + $
                       2*B_2_1*ncd12raisedto2*ncd21*ncd22 - $
		       3*B_3_0*ncd12raisedto2*ncd22raisedto2) / detnewcdraisedto3
   nPV1_9  =  (-3*A_0_3*ncd11raisedto3*ncd21 + $
                       A_1_2*ncd11raisedto3*ncd22 + $
                       2*A_1_2*ncd11raisedto2*ncd12*ncd21 - $
                       2*A_2_1*ncd11raisedto2*ncd12*ncd22 - $
                       A_2_1*ncd11*ncd12raisedto2*ncd21 + $
                       3*A_3_0*ncd11*ncd12raisedto2*ncd22 - $
                       3*B_0_3*ncd11raisedto2*ncd12*ncd21 + $
                       B_1_2*ncd11raisedto2*ncd12*ncd22 + $
                       2*B_1_2*ncd11*ncd12raisedto2*ncd21 - $
                       2*B_2_1*ncd11*ncd12raisedto2*ncd22 - $
                       B_2_1*ncd12raisedto3*ncd21 + $
		       3*B_3_0*ncd12raisedto3*ncd22) / detnewcdraisedto3
   nPV1_10 =  (A_0_3*ncd11raisedto4 - $
                       A_1_2*ncd11raisedto3*ncd12 + $
                       A_2_1*ncd11raisedto2*ncd12raisedto2 - $
                       A_3_0*ncd11*ncd12raisedto3 + $
                       B_0_3*ncd11raisedto3*ncd12 - $
                       B_1_2*ncd11raisedto2*ncd12raisedto2 + $
                       B_2_1*ncd11*ncd12raisedto3 - $
		       B_3_0*ncd12raisedto4) / detnewcdraisedto3
   nPV1_12 =  (A_0_4*ncd11*ncd21raisedto4 - $
                       A_1_3*ncd11*ncd21raisedto3*ncd22 + $
                       A_2_2*ncd11*ncd21raisedto2*ncd22raisedto2 - $
                       A_3_1*ncd11*ncd21*ncd22raisedto3 + $
                       A_4_0*ncd11*ncd22raisedto4 + $
                       B_0_4*ncd12*ncd21raisedto4 - $
                       B_1_3*ncd12*ncd21raisedto3*ncd22 + $
                       B_2_2*ncd12*ncd21raisedto2*ncd22raisedto2 - $
                       B_3_1*ncd12*ncd21*ncd22raisedto3 + $
		       B_4_0*ncd12*ncd22raisedto4) / detnewcdraisedto4
   nPV1_13 =  (-4*A_0_4*ncd11raisedto2*ncd21raisedto3 + $
                       3*A_1_3*ncd11raisedto2*ncd21raisedto2*ncd22 + $
                       A_1_3*ncd11*ncd12*ncd21raisedto3 - $
                       2*A_2_2*ncd11raisedto2*ncd21*ncd22raisedto2 - $
                       2*A_2_2*ncd11*ncd12*ncd21raisedto2*ncd22 + $
                       A_3_1*ncd11raisedto2*ncd22raisedto3 + $
                       3*A_3_1*ncd11*ncd12*ncd21*ncd22raisedto2 - $
                       4*A_4_0*ncd11*ncd12*ncd22raisedto3 - $
                       4*B_0_4*ncd11*ncd12*ncd21raisedto3 + $
                       3*B_1_3*ncd11*ncd12*ncd21raisedto2*ncd22 + $
                       B_1_3*ncd12raisedto2*ncd21raisedto3 - $
                       2*B_2_2*ncd11*ncd12*ncd21*ncd22raisedto2 - $
                       2*B_2_2*ncd12raisedto2*ncd21raisedto2*ncd22 + $
                       B_3_1*ncd11*ncd12*ncd22raisedto3 + $
                       3*B_3_1*ncd12raisedto2*ncd21*ncd22raisedto2 - $
		       4*B_4_0*ncd12raisedto2*ncd22raisedto3) / detnewcdraisedto4
   nPV1_14 =  (6*A_0_4*ncd11raisedto3*ncd21raisedto2 - $
                       3*A_1_3*ncd11raisedto3*ncd21*ncd22 - $
                       3*A_1_3*ncd11raisedto2*ncd12*ncd21raisedto2 + $
                       A_2_2*ncd11raisedto3*ncd22raisedto2 + $
                       4*A_2_2*ncd11raisedto2*ncd12*ncd21*ncd22 + $
                       A_2_2*ncd11*ncd12raisedto2*ncd21raisedto2 - $
                       3*A_3_1*ncd11raisedto2*ncd12*ncd22raisedto2 - $
                       3*A_3_1*ncd11*ncd12raisedto2*ncd21*ncd22 + $
                       6*A_4_0*ncd11*ncd12raisedto2*ncd22raisedto2 + $
                       6*B_0_4*ncd11raisedto2*ncd12*ncd21raisedto2 - $
                       3*B_1_3*ncd11raisedto2*ncd12*ncd21*ncd22 - $
                       3*B_1_3*ncd11*ncd12raisedto2*ncd21raisedto2 + $
                       B_2_2*ncd11raisedto2*ncd12*ncd22raisedto2 + $
                       4*B_2_2*ncd11*ncd12raisedto2*ncd21*ncd22 + $
                       B_2_2*ncd12raisedto3*ncd21raisedto2 - $
                       3*B_3_1*ncd11*ncd12raisedto2*ncd22raisedto2 - $
                       3*B_3_1*ncd12raisedto3*ncd21*ncd22 + $
		       6*B_4_0*ncd12raisedto3*ncd22raisedto2) / detnewcdraisedto4
   nPV1_15 =  (-4*A_0_4*ncd11raisedto4*ncd21 + $
                       A_1_3*ncd11raisedto4*ncd22 + $
                       3*A_1_3*ncd11raisedto3*ncd12*ncd21 - $
                       2*A_2_2*ncd11raisedto3*ncd12*ncd22 - $
                       2*A_2_2*ncd11raisedto2*ncd12raisedto2*ncd21 + $
                       3*A_3_1*ncd11raisedto2*ncd12raisedto2*ncd22 + $
                       A_3_1*ncd11*ncd12raisedto3*ncd21 - $
                       4*A_4_0*ncd11*ncd12raisedto3*ncd22 - $
                       4*B_0_4*ncd11raisedto3*ncd12*ncd21 + $
                       B_1_3*ncd11raisedto3*ncd12*ncd22 + $
                       3*B_1_3*ncd11raisedto2*ncd12raisedto2*ncd21 - $
                       2*B_2_2*ncd11raisedto2*ncd12raisedto2*ncd22 - $
                       2*B_2_2*ncd11*ncd12raisedto3*ncd21 + $
                       3*B_3_1*ncd11*ncd12raisedto3*ncd22 + $
                       B_3_1*ncd12raisedto4*ncd21 - $
		       4*B_4_0*ncd12raisedto4*ncd22) / detnewcdraisedto4
   nPV1_16 =  (A_0_4*ncd11raisedto5 - $
                       A_1_3*ncd11raisedto4*ncd12 + $
                       A_2_2*ncd11raisedto3*ncd12raisedto2 - $
                       A_3_1*ncd11raisedto2*ncd12raisedto3 + $
                       A_4_0*ncd11*ncd12raisedto4 + $
                       B_0_4*ncd11raisedto4*ncd12 - $
                       B_1_3*ncd11raisedto3*ncd12raisedto2 + $
                       B_2_2*ncd11raisedto2*ncd12raisedto3 - $
                       B_3_1*ncd11*ncd12raisedto4 + $
		       B_4_0*ncd12raisedto5) / detnewcdraisedto4
   nPV2_4  =  (A_0_2*ncd11raisedto2*ncd21 - $
                       A_1_1*ncd11*ncd12*ncd21 + $
                       A_2_0*ncd12raisedto2*ncd21 + $
                       B_0_2*ncd11raisedto2*ncd22 - $
                       B_1_1*ncd11*ncd12*ncd22 + $
		       B_2_0*ncd12raisedto2*ncd22) /detnewcdraisedto2
   nPV2_5  =  (-2*A_0_2*ncd11*ncd21raisedto2 + $
                       A_1_1*ncd11*ncd21*ncd22 + $
                       A_1_1*ncd12*ncd21raisedto2 - $
                       2*A_2_0*ncd12*ncd21*ncd22 - $
                       2*B_0_2*ncd11*ncd21*ncd22 + $
                       B_1_1*ncd11*ncd22raisedto2 + $
                       B_1_1*ncd12*ncd21*ncd22 - $
		       2*B_2_0*ncd12*ncd22raisedto2) /detnewcdraisedto2
   nPV2_6  =  (A_0_2*ncd21raisedto3 - $
                       A_1_1*ncd21raisedto2*ncd22 + $
                       A_2_0*ncd21*ncd22raisedto2 + $
                       B_0_2*ncd21raisedto2*ncd22 - $
                       B_1_1*ncd21*ncd22raisedto2 + $
		       B_2_0*ncd22raisedto3) /detnewcdraisedto2
   nPV2_7  =  (A_0_3*ncd11raisedto3*ncd21 - $
                       A_1_2*ncd11raisedto2*ncd12*ncd21 + $
                       A_2_1*ncd11*ncd12raisedto2*ncd21 - $
                       A_3_0*ncd12raisedto3*ncd21 + $
                       B_0_3*ncd11raisedto3*ncd22 - $
                       B_1_2*ncd11raisedto2*ncd12*ncd22 + $
                       B_2_1*ncd11*ncd12raisedto2*ncd22 - $
	               B_3_0*ncd12raisedto3*ncd22) / detnewcdraisedto3
   nPV2_8  =  (-3*A_0_3*ncd11raisedto2*ncd21raisedto2 + $
                       A_1_2*ncd11raisedto2*ncd21*ncd22 + $
                       2*A_1_2*ncd11*ncd12*ncd21raisedto2 - $
                       2*A_2_1*ncd11*ncd12*ncd21*ncd22 - $
                       A_2_1*ncd12raisedto2*ncd21raisedto2 + $
                       3*A_3_0*ncd12raisedto2*ncd21*ncd22 - $
                       3*B_0_3*ncd11raisedto2*ncd21*ncd22 + $
                       B_1_2*ncd11raisedto2*ncd22raisedto2 + $
                       2*B_1_2*ncd11*ncd12*ncd21*ncd22 - $
                       2*B_2_1*ncd11*ncd12*ncd22raisedto2 - $
                       B_2_1*ncd12raisedto2*ncd21*ncd22 + $
		       3*B_3_0*ncd12raisedto2*ncd22raisedto2) / detnewcdraisedto3
   nPV2_9  =  (3*A_0_3*ncd11*ncd21raisedto3 - $
                       2*A_1_2*ncd11*ncd21raisedto2*ncd22 - $
                       A_1_2*ncd12*ncd21raisedto3 + $
                       A_2_1*ncd11*ncd21*ncd22raisedto2 + $
                       2*A_2_1*ncd12*ncd21raisedto2*ncd22 - $
                       3*A_3_0*ncd12*ncd21*ncd22raisedto2 + $
                       3*B_0_3*ncd11*ncd21raisedto2*ncd22 - $
                       2*B_1_2*ncd11*ncd21*ncd22raisedto2 - $
                       B_1_2*ncd12*ncd21raisedto2*ncd22 + $
                       B_2_1*ncd11*ncd22raisedto3 + $
                       2*B_2_1*ncd12*ncd21*ncd22raisedto2 - $
	               3*B_3_0*ncd12*ncd22raisedto3) / detnewcdraisedto3
   nPV2_10 =  (-A_0_3*ncd21raisedto4 + $
                       A_1_2*ncd21raisedto3*ncd22 - $
                       A_2_1*ncd21raisedto2*ncd22raisedto2 + $
                       A_3_0*ncd21*ncd22raisedto3 - $
                       B_0_3*ncd21raisedto3*ncd22 + $
                       B_1_2*ncd21raisedto2*ncd22raisedto2 - $
                       B_2_1*ncd21*ncd22raisedto3 + $
		       B_3_0*ncd22raisedto4) / detnewcdraisedto3
   nPV2_12 =  (A_0_4*ncd11raisedto4*ncd21 - $
                       A_1_3*ncd11raisedto3*ncd12*ncd21 + $
                       A_2_2*ncd11raisedto2*ncd12raisedto2*ncd21 - $
                       A_3_1*ncd11*ncd12raisedto3*ncd21 + $
                       A_4_0*ncd12raisedto4*ncd21 + $
                       B_0_4*ncd11raisedto4*ncd22 - $
                       B_1_3*ncd11raisedto3*ncd12*ncd22 + $
                       B_2_2*ncd11raisedto2*ncd12raisedto2*ncd22 - $
                       B_3_1*ncd11*ncd12raisedto3*ncd22 + $
	               B_4_0*ncd12raisedto4*ncd22) / detnewcdraisedto4
   nPV2_13 =  (-4*A_0_4*ncd11raisedto3*ncd21raisedto2 + $
                       A_1_3*ncd11raisedto3*ncd21*ncd22 + $
                       3*A_1_3*ncd11raisedto2*ncd12*ncd21raisedto2 - $
                       2*A_2_2*ncd11raisedto2*ncd12*ncd21*ncd22 - $
                       2*A_2_2*ncd11*ncd12raisedto2*ncd21raisedto2 + $
                       3*A_3_1*ncd11*ncd12raisedto2*ncd21*ncd22 + $
                       A_3_1*ncd12raisedto3*ncd21raisedto2 - $
                       4*A_4_0*ncd12raisedto3*ncd21*ncd22 - $
                       4*B_0_4*ncd11raisedto3*ncd21*ncd22 + $
                       B_1_3*ncd11raisedto3*ncd22raisedto2 + $
                       3*B_1_3*ncd11raisedto2*ncd12*ncd21*ncd22 - $
                       2*B_2_2*ncd11raisedto2*ncd12*ncd22raisedto2 - $
                       2*B_2_2*ncd11*ncd12raisedto2*ncd21*ncd22 + $
                       3*B_3_1*ncd11*ncd12raisedto2*ncd22raisedto2 + $
                       B_3_1*ncd12raisedto3*ncd21*ncd22 - $
		       4*B_4_0*ncd12raisedto3*ncd22raisedto2) / detnewcdraisedto4
   nPV2_14 =  (6*A_0_4*ncd11raisedto2*ncd21raisedto3 - $
                       3*A_1_3*ncd11raisedto2*ncd21raisedto2*ncd22 - $
                       3*A_1_3*ncd11*ncd12*ncd21raisedto3 + $
                       A_2_2*ncd11raisedto2*ncd21*ncd22raisedto2 + $
                       4*A_2_2*ncd11*ncd12*ncd21raisedto2*ncd22 + $
                       A_2_2*ncd12raisedto2*ncd21raisedto3 - $
                       3*A_3_1*ncd11*ncd12*ncd21*ncd22raisedto2 - $
                       3*A_3_1*ncd12raisedto2*ncd21raisedto2*ncd22 + $
                       6*A_4_0*ncd12raisedto2*ncd21*ncd22raisedto2 + $
                       6*B_0_4*ncd11raisedto2*ncd21raisedto2*ncd22 - $
                       3*B_1_3*ncd11raisedto2*ncd21*ncd22raisedto2 - $
                       3*B_1_3*ncd11*ncd12*ncd21raisedto2*ncd22 + $
                       B_2_2*ncd11raisedto2*ncd22raisedto3 + $
                       4*B_2_2*ncd11*ncd12*ncd21*ncd22raisedto2 + $
                       B_2_2*ncd12raisedto2*ncd21raisedto2*ncd22 - $
                       3*B_3_1*ncd11*ncd12*ncd22raisedto3 - $
                       3*B_3_1*ncd12raisedto2*ncd21*ncd22raisedto2 + $
	               6*B_4_0*ncd12raisedto2*ncd22raisedto3) / detnewcdraisedto4
   nPV2_15 =  (-4*A_0_4*ncd11*ncd21raisedto4 + $
                       3*A_1_3*ncd11*ncd21raisedto3*ncd22 + $
                       A_1_3*ncd12*ncd21raisedto4 - $
                       2*A_2_2*ncd11*ncd21raisedto2*ncd22raisedto2 - $
                       2*A_2_2*ncd12*ncd21raisedto3*ncd22 + $
                       A_3_1*ncd11*ncd21*ncd22raisedto3 + $
                       3*A_3_1*ncd12*ncd21raisedto2*ncd22raisedto2 - $
                       4*A_4_0*ncd12*ncd21*ncd22raisedto3 - $
                       4*B_0_4*ncd11*ncd21raisedto3*ncd22 + $
                       3*B_1_3*ncd11*ncd21raisedto2*ncd22raisedto2 + $
                       B_1_3*ncd12*ncd21raisedto3*ncd22 - $
                       2*B_2_2*ncd11*ncd21*ncd22raisedto3 - $
                       2*B_2_2*ncd12*ncd21raisedto2*ncd22raisedto2 + $
                       B_3_1*ncd11*ncd22raisedto4 + $
                       3*B_3_1*ncd12*ncd21*ncd22raisedto3 - $
		       4*B_4_0*ncd12*ncd22raisedto4) / detnewcdraisedto4
   nPV2_16 =  (A_0_4*ncd21raisedto5 - $
                       A_1_3*ncd21raisedto4*ncd22 + $
                       A_2_2*ncd21raisedto3*ncd22raisedto2 - $
                       A_3_1*ncd21raisedto2*ncd22raisedto3 + $
                       A_4_0*ncd21*ncd22raisedto4 + $
                       B_0_4*ncd21raisedto4*ncd22 - $
                       B_1_3*ncd21raisedto3*ncd22raisedto2 + $
                       B_2_2*ncd21raisedto2*ncd22raisedto3 - $
                       B_3_1*ncd21*ncd22raisedto4 + $
	               B_4_0*ncd22raisedto5) / detnewcdraisedto4

   sxaddpar, h, "PV1_4", nPV1_4
   sxaddpar, h, "PV1_5", nPV1_5
   sxaddpar, h, "PV1_6", nPV1_6
   sxaddpar, h, "PV1_7", nPV1_7
   sxaddpar, h, "PV1_8", nPV1_8
   sxaddpar, h, "PV1_9", nPV1_9
   sxaddpar, h, "PV1_10", nPV1_10
   sxaddpar, h, "PV1_12", nPV1_12
   sxaddpar, h, "PV1_13", nPV1_13
   sxaddpar, h, "PV1_14", nPV1_14
   sxaddpar, h, "PV1_15", nPV1_15
   sxaddpar, h, "PV1_16", nPV1_16
   sxaddpar, h, "PV2_4", nPV2_4
   sxaddpar, h, "PV2_5", nPV2_5
   sxaddpar, h, "PV2_6", nPV2_6
   sxaddpar, h, "PV2_7", nPV2_7
   sxaddpar, h, "PV2_8", nPV2_8
   sxaddpar, h, "PV2_9", nPV2_9
   sxaddpar, h, "PV2_10", nPV2_10
   sxaddpar, h, "PV2_12", nPV2_12
   sxaddpar, h, "PV2_13", nPV2_13
   sxaddpar, h, "PV2_14", nPV2_14
   sxaddpar, h, "PV2_15", nPV2_15
   sxaddpar, h, "PV2_16", nPV2_16

   writefits, outfile, im, h

end

