;+
; NAME: 
;   writecat
;
; PURPOSE: 
;   Write a catalog structure to disk.  See description of the data structure below.
;
; CALLING SEQUENCE: 
;   writecat, filename, cat, h
;       
; INPUTS:
;   filename - Output file to save to.
;   cat      - Catalog structure.    
;
; OPTIONAL INPUT KEYWORD PARAMETERS:
;   h        - Header string array containing FITS-like header cards
;
; OUTPUTS: 
;   The catalog is saved to disk as filename.
;
; COMMENTS:
;   A catalog file is an ASCII text file containing
;   photometry extracted from (generally) a single image and header metadata in a
;   FITS-like format (similar to spec files).  Flux measurements of sources in the
;   catalog are stored as magnitudes; zeropoints describing the conversion back to counts.
;   will be given in the header.  The data structure has the following variables:
;     ra, dec, mag, unc, x, y
;   (On disk, unc is written as emag in the column header).
;
; Last modified 29 May 2013.  Documentation added 3 July 2022.
;-


pro writecat, filename, cat, h

  openw, 1, filename
  inline = ''
  for i = 0, n_elements(h)-1 do begin
    printf, 1, '# '+h[i]
  endfor
  printf, 1, '# END'

  printf,1, '#ra          dec         mag     emag   x         y'
  for s = 0, n_elements(cat)-1 do begin
      printf, 1, fpr(cat[s].ra,3.7), ' ', fpr(cat[s].dec,3.7), ' ', fpr(cat[s].mag,3.3), ' ', fpr(cat[s].unc,2.3), ' ', fpr(cat[s].x,5.2), ' ', fpr(cat[s].y,5.2)
  endfor


  close, 1

end

