;+
; NAME:
;       fixlampstr
;
; PURPOSE:
;       If a lamp is broken, edit a header value to turn its indicator off.
;
; CALLING SEQUENCE:
;       fixlampstr, lampstr, badarclist
;
; EXPLANATION:
;       Sometimes an arc lamp breaks, so it is 'on' according to the headers
;       but not actually working.  This turns the values back 'off'.
;       Does not edit the header itself in any way!
;
; INPUTS:
;       lampstr - LAMPS keyword.  Doesn't recognize new individual 
;                 lamp keywords.
;       badarclist - List of bad arcs (string array).
;
; OUTPUTS:
;       lampstr is changed.
;
; NOTES:
;       Not used in years and not recently tested.
;       It might be better to put this check into lrisprepare, although that
;       would require reprocessing a night if the issue is found after running
;       the pipeline.
;
;-
;------------------------------------------------------------------------------

pro fixlampstr, lampstr, badarclist

      if badarclist[0] ne '' then begin
         ;lampstr = sxpar(header,'LAMPS')
         lamparr = fix(strsplit(lampstr,',',/extract))
         ;arclamps[f] = lampstr
         if total(badarclist eq 'hg' or badarclist eq 'mercury')  then lampstr =                     '0'+strmid(lampstr,1)
         if total(badarclist eq 'ne' or badarclist eq 'neon')     then lampstr = strmid(lampstr,0,2)+'0'+strmid(lampstr,3)
         if total(badarclist eq 'ar' or badarclist eq 'argon')    then lampstr = strmid(lampstr,0,4)+'0'+strmid(lampstr,5)
         if total(badarclist eq 'cd' or badarclist eq 'cadmium')  then lampstr = strmid(lampstr,0,6)+'0'+strmid(lampstr,7)
         if total(badarclist eq 'zn' or badarclist eq 'zinc')     then lampstr = strmid(lampstr,0,8)+'0'+strmid(lampstr,9)
         if total(badarclist eq 'hal' or badarclist eq 'halogen') then lampstr = strmid(lampstr,0,10)+'0'+strmid(lampstr,11)
         ; doesn't recognize new lamps yet, but won't erase them.
      endif


end

