;+
; NAME:
;       ltranspose
;
; PURPOSE:
;       Transposes a spectrum to reverse X and Y axes.
;
; CALLING SEQUENCE:
;       ltranspose, array, header
;
; EXPLANATION:
;       Reverses the axes of a spectrum to better match monitor dimentions
;       and to be more intuitive/consistent.  Updates related header keywords.
;
; INPUTS/OUTPUTS:
;       array - The data array, already read in from disk.
;       header - The header, already read in from disk.
;
; NOTES:
;       Nominally for LRIS but aside from the BINNING keyword the functionality
;       is general.
;
;-
;------------------------------------------------------------------------------

pro hswap, header, hkey1, hkey2
   hold1 = sxpar(header, hkey1, comment=comment1, count=check1)
   hold2 = sxpar(header, hkey2, comment=comment2, count=check2)
   if check1 eq 0 and check2 eq 0 then return
   if n_elements(comment2) gt 0 then sxaddpar, header, hkey1, hold2, comment2 else $
                                     sxaddpar, header, hkey1, hold2, /savecomment
   if n_elements(comment1) gt 0 then sxaddpar, header, hkey2, hold1, comment1 else $
                                     sxaddpar, header, hkey2, hold1, /savecomment
end

pro ltranspose, array, header

   array = transpose(array)

   hswap, header, 'NAXIS1', 'NAXIS2'

   hswap, header, 'LTV1', 'LTV2'
   hswap, header, 'CDELT1', 'CDELT2'
   hswap, header, 'XBIN', 'YBIN'

   ;hswap, header, 'LTM2_1', 'LTM2_2'
   ;hswap, header, 'LTM1_2', 'LTM1_1'
   hswap, header, 'LTM1_1', 'LTM2_2'
   hswap, header, 'LTM1_2', 'LTM2_1'

   hswap, header, 'CD1_1', 'CD1_2'
   hswap, header, 'CD2_2', 'CD2_1'
   ;hswap, header, 'CD1_1', 'CD2_2'
   ;hswap, header, 'CD1_2', 'CD2_1'
   hswap, header, 'CRPIX1', 'CRPIX2'

   ;hswap, header, 'CRVAL1', 'CRVAL2'
   ;hswap, header, 'CTYPE1', 'CTYPE2'

   bin = sxpar(header,'BINNING',comment=comment)
   comment = repstr(comment,'X,Y','Y,X')
   comment = repstr(comment,'native','transposed')
   sxaddpar, header, 'BINNING', bin, comment

end

