;+
; NAME:
;      saveobjectposfile 
;
; PURPOSE:
;      Write to disk a file containing saved aperture and trace properties.
;
; CALLING SEQUENCE:
;      saveobjectposfile, outfile, tr
;
; EXPLANATION:
;      Files like objectpos.txt and userobjectpos.txt are used by LPipe to 
;      store automatically and user-specified apertures for spectrum
;      extraction.  This program creates those files.
;      Some information about the file format is given in the general LPipe
;      documentation.
;
; INPUTS:
;      outfile - Name of the file to write.
;      tr - The aperture/trace IDL structure.
;
; OUTPUTS:
;      The trace/aperture file is written to disk.
; 
;-
;------------------------------------------------------------------------------

pro saveobjectposfile, outfile, tr

    outstrarr = strarr(n_elements(tr))
    for i = 0, n_elements(tr)-1 do outstrarr[i] = trsoutstring(tr[i])
             ;outstr = outstring(trs)
    openw, 7, outfile
    printf, 7, '#LPipe user object positions'
    printf, 7, '#coord=array'
    printf, 7, '#filename                             ycen    rad   background  tracefile  '
    for i = 0, n_elements(tr)-1 do begin
      if tr[i].file ne '' then printf, 7, trsoutstring(tr[i])
;      if tr[i].file ne '' then print, 7, trsoutstring(tr[i])
    endfor
    close, 7

end

